package de.ozgcloud.eingang.xta;

import static org.assertj.core.api.Assertions.*;

import java.math.BigInteger;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.Spy;

class XtaMessageMetaDataMapperTest {

	@Spy
	private final XtaMessageMetaDataMapper mapper = Mappers.getMapper(XtaMessageMetaDataMapper.class);

	@Nested
	class TestMoreMessagesAvailable {

		@Test
		void shouldReturnFalseOnNoMessagesAvailable() {

			var response = mapper.moreMessagesAvailable(buildWithNoMessageAvailable());

			assertThat(response).isFalse();
		}

		private MsgStatusListTypeAndHeaderResponse buildWithNoMessageAvailable() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().noMessageAvailable(true).build();
		}

		@Test
		void shouldReturnFalseOnPendingMessagesNull() {

			var response = mapper.moreMessagesAvailable(buildPendingMessagesNull());

			assertThat(response).isFalse();
		}

		private MsgStatusListTypeAndHeaderResponse buildPendingMessagesNull() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().messageItemsPending(null).build();
		}

		@Test
		void shouldReturnFalseOnNoMessagesPending() {

			var response = mapper.moreMessagesAvailable(buildWithoutPendingMessages());

			assertThat(response).isFalse();
		}

		private MsgStatusListTypeAndHeaderResponse buildWithoutPendingMessages() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().messageItemsPending(null).build();
		}

		@Test
		void shouldReturnTrueOnMessagesPending() {

			var response = mapper.moreMessagesAvailable(buildWithPendingMessages());

			assertThat(response).isTrue();
		}

		private MsgStatusListTypeAndHeaderResponse buildWithPendingMessages() {
			return MsgStatusListTypeAndHeaderResponseTestFactory.createBuilder().messageItemsPending(BigInteger.ONE).build();
		}
	}
}
